@@ -2025,6 +2025,15 @@ class Shape:
 
         self.impl = impl
 
+    @property
+    def api(self):
+        """
+        Returns the native object (``pywin32`` or ``appscript`` obj) of the engine being used.
+
+        .. versionadded:: 0.19.2
+        """
+        return self.impl.api
+
     @property
     def name(self):
         """
@@ -2115,6 +2124,40 @@ class Shape:
         """
         self.impl.activate()
 
+    def scale_height(self, factor, relative_to_original_size=False, scale='scale_from_top_left'):
+        """
+        factor : float
+            For example 1.5 to scale it up to 150%
+
+        relative_to_original_size : bool, optional
+            If ``False``, it scales relative to current height (default).
+            For ``True`` must be a picture or OLE object.
+
+        scale : str, optional
+            One of ``scale_from_top_left`` (default), ``scale_from_bottom_right``, ``scale_from_middle``
+
+        .. versionadded:: 0.19.2
+        """
+        self.impl.scale_height(factor=factor, relative_to_original_size=relative_to_original_size,
+                               scale=scale)
+
+    def scale_width(self, factor, relative_to_original_size=False, scale='scale_from_top_left'):
+        """
+        factor : float
+            For example 1.5 to scale it up to 150%
+
+        relative_to_original_size : bool, optional
+            If ``False``, it scales relative to current width (default).
+            For ``True`` must be a picture or OLE object.
+
+        scale : str, optional
+            One of ``scale_from_top_left`` (default), ``scale_from_bottom_right``, ``scale_from_middle``
+
+        .. versionadded:: 0.19.2
+        """
+        self.impl.scale_width(factor=factor, relative_to_original_size=relative_to_original_size,
+                              scale=scale)
+
     @property
     def parent(self):
         """
@@ -2491,7 +2534,7 @@ class Picture:
         name = self.name
 
         # todo: link_to_file, save_with_document
-        picture = self.parent.pictures.add(filename, left=left, top=top, width=width, height=height)
+        picture = self.parent.pictures.add(filename, left=left, top=top, width=width, height=height, scale=False)
         self.delete()
 
         picture.name = name
@@ -2516,7 +2559,8 @@ class Pictures(Collection):
     def parent(self):
         return Sheet(impl=self.impl.parent)
 
-    def add(self, image, link_to_file=False, save_with_document=True, left=0, top=0, width=None, height=None, name=None, update=False):
+    def add(self, image, link_to_file=False, save_with_document=True, left=0, top=0, width=None, height=None,
+            name=None, update=False, scale=1):
         """
         Adds a picture to the specified sheet.
 
@@ -2607,6 +2651,11 @@ class Pictures(Collection):
             filename, link_to_file, save_with_document, left, top, width, height
         ))
 
+        if scale:
+            # By default, Excel usually distorts the width/height. This corrects it.
+            self.parent.shapes[picture.name].scale_width(factor=scale, relative_to_original_size=True)
+            self.parent.shapes[picture.name].scale_height(factor=scale, relative_to_original_size=True)
+
         if name is not None:
             picture.name = name
         return picture
